%define anolies_release 1
%global libsymbolsuffix ()(%{__isa_bits}bit)
%global libdecor_majver 0

Name:           SDL2
Version:        2.28.2
Release:        %{anolies_release}%{?dist}
Summary:        Cross-platform multimedia library
License:        zlib and MIT
URL:            http://www.libsdl.org/
Source0:        http://www.libsdl.org/release/%{name}-%{version}.tar.gz

# Prefer Wayland by default
Patch0:         SDL2-2.0.22-prefer-wayland.patch

BuildRequires:  git-core
BuildRequires:  libXi-devel
BuildRequires:  vulkan-devel
BuildRequires:  libX11-devel
BuildRequires:  libdrm-devel
BuildRequires:  systemd-devel
BuildRequires:  libXext-devel
BuildRequires:  alsa-lib-devel
BuildRequires:  libXrandr-devel
BuildRequires:  mesa-libGL-devel
BuildRequires:  libXrender-devel
BuildRequires:  libXcursor-devel
BuildRequires:  mesa-libGLU-devel
BuildRequires:  mesa-libgbm-devel
BuildRequires:  mesa-libEGL-devel
BuildRequires:  libXinerama-devel
BuildRequires:  mesa-libGLES-devel
BuildRequires:  libXScrnSaver-devel
BuildRequires:  cmake make gcc gcc-c++
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(libdecor-%{libdecor_majver})

Requires:       (libdecor-%{libdecor_majver}.so.%{libdecor_majver}%{libsymbolsuffix} if libwayland-client)

%description
Simple DirectMedia Layer (SDL) is a cross-platform development library that
provides low-level access to audio, keyboard, mouse, joystick, and graphics
hardware via OpenGL and Direct3D. It is designed to provide a simple and easy-
to-use API, while also being highly portable across different operating systems.

SDL was first released in 1998 and has been used in a wide range of applications,
from video games to multimedia applications to scientific simulations. It
supports a variety of programming languages, including C, C++, Python, Ruby,
and Perl, and runs on a wide range of platforms, including Windows, Linux,
macOS, iOS, and Android.

The library provides an abstraction layer that shields developers from the
complexities of working with low-level multimedia hardware. It allows developers
to write code that is independent of specific hardware or operating systems,
making it easier to create cross-platform applications.

SDL is also highly extensible, with support for plugins and add-ons. This makes it
possible for developers to add new features and functionality to their applications
without having to modify the core SDL library.

SDL provides a number of key features, including:

Audio: SDL provides a simple and easy-to-use API for working with audio
hardware. It supports both playback and recording of audio, and provides
low-latency access to the hardware.

Graphics: SDL provides a cross-platform API for working with graphics
hardware. It supports 2D and 3D rendering via OpenGL and Direct3D, and
provides access to graphics hardware acceleration.

Input: SDL provides a unified API for working with input devices, including
keyboards, mice, and joysticks. It supports both polling and event-driven
input, and provides access to advanced input features such as multi-touch
and gesture recognition.

Threading: SDL provides a simple and portable API for working with threads
and synchronization primitives. It makes it easy to write multithreaded
applications that can take advantage of modern hardware.

Timers: SDL provides a high-resolution timer API that can be used for accurate
timing and synchronization of multimedia operations.

Overall, SDL is a powerful and flexible development library that simplifies the task
of creating cross-platform multimedia applications. Its ease of use, portability,
and extensibility have made it a popular choice among developers and hobbyists
alike.

%package devel
Summary:        Files needed to develop Simple DirectMedia Layer applications
Requires:       %{name} = %{version}-%{release}
Requires:       libX11-devel
Requires:       mesa-libEGL-devel
Requires:       mesa-libGLES-devel

%description devel
This package provides the libraries, include files, and other resources needed for
developing SDL applications.

%package static
Summary:        Static libraries for SDL2
Requires:       %{name}-devel = %{version}-%{release}

%description static
Static libraries for SDL2.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-%{version} -p1
sed -i -e 's/\r//g' TODO.txt README.md WhatsNew.txt BUGS.txt LICENSE.txt CREDITS.txt README-SDL.txt

%build
# Deal with new CMake policy around whitespace in LDFLAGS...
export LDFLAGS="%{shrink:%{build_ldflags}}"

%cmake \
    -DSDL_ESD=OFF \
    -DSDL_NAS=OFF \
    -DSDL_ALSA=ON \
    -DSDL_SSE3=OFF \
    -DSDL_ARTS=OFF \
    -DSDL_JACK=OFF \
    -DSDL_JACK=OFF \
    -DSDL_STATIC=ON \
    -DSDL_STATIC=ON \
    -DSDL_RPATH=OFF \
    -DSDL_LOADSO=OFF \
    -DSDL_WAYLAND=ON \
    -DSDL_VIDEO_VULKAN=ON \
    -DSDL_PIPEWIRE_SHARED=ON \
    -DSDL_PULSEAUDIO_SHARED=ON \
    -DSDL_WAYLAND_LIBDECOR=ON \
    -DSDL_VENDOR_INFO="%{_vendor} %{anolis_ver}"

%cmake_build

%install
%cmake_install

%generate_compatibility_deps

%files
%license LICENSE.txt
%dir %{abidir}
%{abidir}/libSDL2-2.0.dump
%{_libdir}/libSDL2-2.0.so.0*

%files devel
%{_libdir}/lib*.so
%{_includedir}/SDL2
%{_bindir}/*-config
%{_datadir}/aclocal/*
%{_libdir}/libSDL2main.a
%{_libdir}/libSDL2_test.a
%dir %{_libdir}/cmake/SDL2
%{_libdir}/pkgconfig/sdl2.pc
%{_libdir}/cmake/SDL2/SDL2Config*.cmake
%{_libdir}/cmake/SDL2/SDL2Targets*.cmake
%{_libdir}/cmake/SDL2/SDL2mainTargets*.cmake
%{_libdir}/cmake/SDL2/SDL2testTargets*.cmake
%{_libdir}/cmake/SDL2/sdlfind.cmake

%files static
%license LICENSE.txt
%{_libdir}/libSDL2.a
%{_libdir}/cmake/SDL2/SDL2staticTargets*.cmake

%files doc
%doc BUGS.txt CREDITS.txt README-SDL.txt
%doc README.md TODO.txt WhatsNew.txt

%changelog
* Sun Aug 6 2023 Funda Wang <fundawang@yeah.net> - 2.28.2-1
- New version 2.28.2

* Thu Apr 13 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 2.26.4-2
- Update some description

* Sat Mar 11 2023 Funda Wang <fundawang@yeah.net> - 2.26.4-1
- New version 2.26.4
- Disable jack support, we don't have it yet

* Fri Feb 10 2023 Funda Wang <fundawang@yeah.net> - 2.26.3-1
- New version 2.26.3

* Tue Jan 24 2023 Funda Wang <fundawang@yeah.net> - 2.26.2-1
- New version 2.26.2

* Sun Nov 27 2022 Funda Wang <fundawang@yeah.net> - 2.26.0-1
- New verion 2.26.0
- Remove multilib stuffs
- Disable loadso as what debian does

* Fri Oct 28 2022 happy_orange <songnannan@linux.alibaba.com> - 2.24.0-1
- Init package from upstream
